summaryrefslogtreecommitdiff
path: root/ext
diff options
context:
space:
mode:
Diffstat (limited to 'ext')
-rw-r--r--ext/aom/gstav1enc.c2
-rw-r--r--ext/assrender/gstassrender.c4
-rw-r--r--ext/closedcaption/gstcea708decoder.c2
-rw-r--r--ext/closedcaption/gstceaccoverlay.c2
-rw-r--r--ext/closedcaption/raw_decoder.c2
-rw-r--r--ext/closedcaption/sliced.h2
-rw-r--r--ext/colormanagement/gstlcms.c2
-rw-r--r--ext/curl/gstcurlhttpsrc.h2
-rw-r--r--ext/dash/gstdashdemux.c14
-rw-r--r--ext/dash/gstmpdparser.c2
-rw-r--r--ext/directfb/dfbvideosink.c2
-rw-r--r--ext/dtls/gstdtlsconnection.h2
-rw-r--r--ext/hls/gsthlsdemux.c4
-rw-r--r--ext/kate/gstkatedec.c2
-rw-r--r--ext/kate/gstkateenc.c2
-rw-r--r--ext/ladspa/gstladspa.c2
-rw-r--r--ext/libmms/gstmms.c7
-rw-r--r--ext/lv2/gstlv2filter.c4
-rw-r--r--ext/lv2/gstlv2utils.c4
-rw-r--r--ext/mpeg2enc/gstmpeg2enc.cc2
-rw-r--r--ext/mpeg2enc/gstmpeg2encoptions.cc2
-rw-r--r--ext/neon/gstneonhttpsrc.c6
-rw-r--r--ext/opencv/MotionCells.cpp2
-rw-r--r--ext/opencv/gstcvdilate.cpp2
-rw-r--r--ext/opencv/gstcvdilateerode.cpp2
-rw-r--r--ext/opencv/gstcverode.cpp2
-rw-r--r--ext/opencv/gstcvsmooth.cpp2
-rw-r--r--ext/opencv/gstdewarp.cpp22
-rw-r--r--ext/opencv/gstdisparity.cpp2
-rw-r--r--ext/opencv/gstedgedetect.cpp2
-rw-r--r--ext/opencv/gstfaceblur.cpp4
-rw-r--r--ext/opencv/gstfacedetect.cpp2
-rw-r--r--ext/opencv/gstgrabcut.cpp2
-rw-r--r--ext/opencv/gstretinex.cpp8
-rw-r--r--ext/opencv/gstsegmentation.cpp12
-rw-r--r--ext/opencv/gstskindetect.cpp2
-rw-r--r--ext/opencv/gsttextoverlay.cpp2
-rw-r--r--ext/resindvd/gstmpegdemux.c2
-rw-r--r--ext/resindvd/resindvdsrc.c2
-rw-r--r--ext/resindvd/rsninputselector.c2
-rw-r--r--ext/rtmp/gstrtmpsrc.c2
-rw-r--r--ext/soundtouch/gstpitch.cc2
-rw-r--r--ext/spandsp/gstdtmfdetect.c2
-rw-r--r--ext/spandsp/gsttonegeneratesrc.c2
-rw-r--r--ext/srt/gstsrtobject.c2
-rw-r--r--ext/srtp/gstsrtpdec.c8
-rw-r--r--ext/srtp/gstsrtpenc.c6
-rw-r--r--ext/ttml/subtitle.h4
-rw-r--r--ext/ttml/ttmlparse.c2
-rw-r--r--ext/vulkan/vkdownload.c2
-rw-r--r--ext/vulkan/vkfullscreenrender.c2
-rw-r--r--ext/vulkan/vkshader.c4
-rw-r--r--ext/vulkan/vkupload.c2
-rw-r--r--ext/vulkan/vkviewconvert.c2
-rw-r--r--ext/wayland/gstwaylandsink.c2
-rw-r--r--ext/wayland/wlbuffer.c2
-rw-r--r--ext/webp/gstwebpdec.c2
-rw-r--r--ext/webrtc/gstwebrtcbin.c12
-rw-r--r--ext/webrtc/transportreceivebin.c2
-rw-r--r--ext/webrtc/webrtcsdp.c2
-rw-r--r--ext/webrtcdsp/gstwebrtcdsp.cpp6
-rw-r--r--ext/webrtcdsp/gstwebrtcechoprobe.cpp2
-rw-r--r--ext/webrtcdsp/gstwebrtcechoprobe.h2
-rw-r--r--ext/wildmidi/gstwildmididec.c2
-rw-r--r--ext/wpe/gstwpesrc.cpp2
-rw-r--r--ext/x265/gstx265enc.c4
-rw-r--r--ext/zbar/gstzbar.c4
67 files changed, 117 insertions, 116 deletions
diff --git a/ext/aom/gstav1enc.c b/ext/aom/gstav1enc.c
index 0fc441a4b..2c7be2800 100644
--- a/ext/aom/gstav1enc.c
+++ b/ext/aom/gstav1enc.c
@@ -331,7 +331,7 @@ gst_av1_enc_class_init (GstAV1EncClass * klass)
g_object_class_install_property (gobject_class, PROP_MIN_QUANTIZER,
g_param_spec_uint ("min-quantizer", "Minimum (best quality) quantizer",
- "Mininum (best quality) quantizer",
+ "Minimum (best quality) quantizer",
0, G_MAXUINT, DEFAULT_MIN_QUANTIZER,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
diff --git a/ext/assrender/gstassrender.c b/ext/assrender/gstassrender.c
index e3886eebe..e99458bf2 100644
--- a/ext/assrender/gstassrender.c
+++ b/ext/assrender/gstassrender.c
@@ -832,7 +832,7 @@ gst_ass_render_negotiate (GstAssRender * render, GstCaps * caps)
}
if (upstream_has_meta || caps_has_meta) {
- /* Send caps immediatly, it's needed by GstBaseTransform to get a reply
+ /* Send caps immediately, it's needed by GstBaseTransform to get a reply
* from allocation query */
ret = gst_pad_set_caps (render->srcpad, overlay_caps);
@@ -875,7 +875,7 @@ gst_ass_render_negotiate (GstAssRender * render, GstCaps * caps)
render->window_height = height;
gst_ass_render_update_render_size (render);
- /* For backward compatbility, we will prefer bliting if downstream
+ /* For backward compatibility, we will prefer bliting if downstream
* allocation does not support the meta. In other case we will prefer
* attaching, and will fail the negotiation in the unlikely case we are
* force to blit, but format isn't supported. */
diff --git a/ext/closedcaption/gstcea708decoder.c b/ext/closedcaption/gstcea708decoder.c
index bc2eb6d78..b2e9f98b6 100644
--- a/ext/closedcaption/gstcea708decoder.c
+++ b/ext/closedcaption/gstcea708decoder.c
@@ -1021,7 +1021,7 @@ gst_cea708dec_show_pango_window (Cea708Dec * decoder, guint window_id)
}
if (!display) {
- GST_DEBUG ("No visible text, skiping rendering");
+ GST_DEBUG ("No visible text, skipping rendering");
return;
}
diff --git a/ext/closedcaption/gstceaccoverlay.c b/ext/closedcaption/gstceaccoverlay.c
index 0b02d41c6..0d1b3b597 100644
--- a/ext/closedcaption/gstceaccoverlay.c
+++ b/ext/closedcaption/gstceaccoverlay.c
@@ -1468,7 +1468,7 @@ gst_cea_cc_overlay_process_packet (GstCeaCcOverlay * overlay, guint8 cc_type)
* @overlay: The #GstCeaCcOverlay
* @user_data: The #GstMpegVideoCCData to decode
*
- * decode closed caption data and render when neccesary
+ * decode closed caption data and render when necessary
* in struct GstMpegVideoCCData type's user_data's data field, 3 byte's data construct 1 cc_data_pkt
*
* A cc_data_pkt is 3 bytes as follows:
diff --git a/ext/closedcaption/raw_decoder.c b/ext/closedcaption/raw_decoder.c
index 9e7415a55..c6d968312 100644
--- a/ext/closedcaption/raw_decoder.c
+++ b/ext/closedcaption/raw_decoder.c
@@ -1130,7 +1130,7 @@ vbi3_raw_decoder_services (vbi3_raw_decoder * rd)
* $return
* Set of data services $rd will be decode after the change.
* Can be zero if the sampling parameters are invalid or some
- * other error occured.
+ * other error occurred.
*/
/* Attn: strict must be int for compatibility with libzvbi 0.2 (-1 == 0) */
vbi_service_set
diff --git a/ext/closedcaption/sliced.h b/ext/closedcaption/sliced.h
index e5c24b66e..36f922dbf 100644
--- a/ext/closedcaption/sliced.h
+++ b/ext/closedcaption/sliced.h
@@ -320,7 +320,7 @@ typedef unsigned int vbi_service_set;
*/
typedef struct {
/**
- * A @ref VBI_SLICED_ symbol identifying the data service. Under cirumstances
+ * A @ref VBI_SLICED_ symbol identifying the data service. Under circumstances
* (see VBI_SLICED_TELETEXT_B) this can be a set of VBI_SLICED_ symbols.
*/
uint32_t id;
diff --git a/ext/colormanagement/gstlcms.c b/ext/colormanagement/gstlcms.c
index acb9de99e..fc94697cc 100644
--- a/ext/colormanagement/gstlcms.c
+++ b/ext/colormanagement/gstlcms.c
@@ -99,7 +99,7 @@ gst_lcms_lookup_method_get_type (void)
"Precalculate lookup table (takes a long time getting READY)",
"precalculated"},
{GST_LCMS_LOOKUP_METHOD_CACHED,
- "Calculate and cache color replacement values on first occurence",
+ "Calculate and cache color replacement values on first occurrence",
"cached"},
{0, NULL, NULL},
};
diff --git a/ext/curl/gstcurlhttpsrc.h b/ext/curl/gstcurlhttpsrc.h
index 4bf0849e9..36d1de4f7 100644
--- a/ext/curl/gstcurlhttpsrc.h
+++ b/ext/curl/gstcurlhttpsrc.h
@@ -98,7 +98,7 @@ typedef enum
#ifdef CURL_VERSION_HTTP2
GSTCURL_HTTP_VERSION_2_0,
#endif
- GSTCURL_HTTP_NOT, /* For future use, incase not HTTP protocol! */
+ GSTCURL_HTTP_NOT, /* For future use if HTTP protocol not used! */
GSTCURL_HTTP_VERSION_MAX
} GstCurlHttpVersion;
diff --git a/ext/dash/gstdashdemux.c b/ext/dash/gstdashdemux.c
index d011f2310..f550b30ce 100644
--- a/ext/dash/gstdashdemux.c
+++ b/ext/dash/gstdashdemux.c
@@ -145,7 +145,7 @@
* When requested (with GST_SEEK_FLAG_TRICKMODE_KEY_UNIT) and if the format
* is supported (ISOBMFF profiles), dashdemux can download only keyframes
* in order to provide fast forward/reverse playback without exceeding the
- * available bandwith/cpu/memory usage.
+ * available bandwidth/cpu/memory usage.
*
* This is done in two parts:
* 1) Parsing ISOBMFF atoms to detect the location of keyframes and only
@@ -178,7 +178,7 @@
*
* The main reason for doing keyframe-only downloads is for trick-modes
* (i.e. being able to do fast reverse/forward playback with limited
- * bandwith/cpu/memory).
+ * bandwidth/cpu/memory).
*
* Downloading all keyframes might not be the optimal solution, especially
* at high playback rates, since the time taken to download the keyframe
@@ -252,13 +252,13 @@
* buffering_level.
*
* The smaller the buffering level is (i.e. the closer we are between
- * current and downstream), the more aggresively we skip forward (and
+ * current and downstream), the more aggressively we skip forward (and
* guarantee the keyframe will be downloaded, decoded and displayed in
* time). And the higher the buffering level, the least aggresivelly
* we need to skip forward (and therefore display more frames per
* second).
*
- * Right now the threshold for agressive switching is set to 3
+ * Right now the threshold for aggressive switching is set to 3
* average_download_time. Below that buffering level we set the target time
* to at least 3 average_download_time distance beyond the
* qos_earliest_time.
@@ -1135,7 +1135,7 @@ gst_dash_demux_get_video_input_caps (GstDashDemux * demux,
if (stream == NULL)
return NULL;
- /* if bitstreamSwitching is true we dont need to swich pads on resolution change */
+ /* if bitstreamSwitching is true we don't need to switch pads on resolution change */
if (!gst_mpd_client_get_bitstream_switching_flag (stream)) {
width = gst_mpd_client_get_video_stream_width (stream);
height = gst_mpd_client_get_video_stream_height (stream);
@@ -1169,7 +1169,7 @@ gst_dash_demux_get_audio_input_caps (GstDashDemux * demux,
if (stream == NULL)
return NULL;
- /* if bitstreamSwitching is true we dont need to swich pads on rate/channels change */
+ /* if bitstreamSwitching is true we don't need to switch pads on rate/channels change */
if (!gst_mpd_client_get_bitstream_switching_flag (stream)) {
channels = gst_mpd_client_get_audio_stream_num_channels (stream);
rate = gst_mpd_client_get_audio_stream_rate (stream);
@@ -1923,7 +1923,7 @@ gst_dash_demux_stream_get_target_time (GstDashDemux * dashdemux,
"MUST SKIP to at least %" GST_TIME_FORMAT " (was %" GST_TIME_FORMAT ")",
GST_TIME_ARGS (ret), GST_TIME_ARGS (min_position));
} else if (diff < 4 * dashstream->average_download_time) {
- /* Go forward a bit less aggresively (and at most 1s forward) */
+ /* Go forward a bit less aggressively (and at most 1s forward) */
ret = gst_segment_position_from_running_time (&stream->segment,
GST_FORMAT_TIME, min_running + MIN (GST_SECOND,
2 * dashstream->average_download_time));
diff --git a/ext/dash/gstmpdparser.c b/ext/dash/gstmpdparser.c
index b75626cd7..371329667 100644
--- a/ext/dash/gstmpdparser.c
+++ b/ext/dash/gstmpdparser.c
@@ -4706,7 +4706,7 @@ gst_mpd_client_get_adaptation_sets_for_period (GstMpdClient * client,
* to decide which one to use, so we have to resolve them all here
*/
for (list = period->period->AdaptationSets; list;
- /* advanced explicitely below */ ) {
+ /* advanced explicitly below */ ) {
GstAdaptationSetNode *adapt_set = (GstAdaptationSetNode *) list->data;
GList *new_adapt_sets = NULL, *prev, *next;
diff --git a/ext/directfb/dfbvideosink.c b/ext/directfb/dfbvideosink.c
index 2e44872c2..ae042e6eb 100644
--- a/ext/directfb/dfbvideosink.c
+++ b/ext/directfb/dfbvideosink.c
@@ -52,7 +52,7 @@
* application, that means it won't handle navigation events and won't resize
* the #GstDfbVideoSink:surface to fit video
* frames geometry. Application has to implement the necessary code to grab
- * informations about the negotiated geometry and resize there
+ * information about the negotiated geometry and resize there
* #GstDfbVideoSink:surface accordingly.
*
* For both modes the element implements a buffer pool allocation system to
diff --git a/ext/dtls/gstdtlsconnection.h b/ext/dtls/gstdtlsconnection.h
index 6260b935b..20751d537 100644
--- a/ext/dtls/gstdtlsconnection.h
+++ b/ext/dtls/gstdtlsconnection.h
@@ -107,7 +107,7 @@ void gst_dtls_connection_close(GstDtlsConnection *);
void gst_dtls_connection_set_send_callback(GstDtlsConnection *, GClosure *);
/*
- * Processes data that has been recevied, the transformation is done in-place.
+ * Processes data that has been received, the transformation is done in-place.
* Returns the length of the plaintext data that was decoded, if no data is available, 0<= will be returned.
*/
gint gst_dtls_connection_process(GstDtlsConnection *, gpointer ptr, gint len);
diff --git a/ext/hls/gsthlsdemux.c b/ext/hls/gsthlsdemux.c
index 80cecf42d..b5fe60e91 100644
--- a/ext/hls/gsthlsdemux.c
+++ b/ext/hls/gsthlsdemux.c
@@ -567,7 +567,7 @@ gst_hls_demux_set_current_variant (GstHLSDemux * hlsdemux,
if (hlsdemux->current_variant != NULL) {
gint i;
- //#warning FIXME: Synching fragments across variants
+ //#warning FIXME: Syncing fragments across variants
// should be done based on media timestamps, and
// discont-sequence-numbers not sequence numbers.
variant->m3u8->sequence_position =
@@ -647,7 +647,7 @@ gst_hls_demux_process_manifest (GstAdaptiveDemux * demux, GstBuffer * buf)
gst_hls_demux_set_current_variant (hlsdemux, variant); // FIXME: inline?
}
- /* get the selected media playlist (unless the inital list was one already) */
+ /* get the selected media playlist (unless the initial list was one already) */
if (!hlsdemux->master->is_simple) {
GError *err = NULL;
diff --git a/ext/kate/gstkatedec.c b/ext/kate/gstkatedec.c
index a2cec0970..dc781b190 100644
--- a/ext/kate/gstkatedec.c
+++ b/ext/kate/gstkatedec.c
@@ -58,7 +58,7 @@
*
* ## Example pipeline
*
- * This explicitely decodes a Kate stream:
+ * This explicitly decodes a Kate stream:
* |[
* gst-launch-1.0 filesrc location=test.ogg ! oggdemux ! katedec ! fakesink silent=TRUE
* ]|
diff --git a/ext/kate/gstkateenc.c b/ext/kate/gstkateenc.c
index d2cbeb0c7..2e62cb87b 100644
--- a/ext/kate/gstkateenc.c
+++ b/ext/kate/gstkateenc.c
@@ -198,7 +198,7 @@ gst_kate_enc_class_init (GstKateEncClass * klass)
0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
g_object_class_install_property (gobject_class, ARG_KEEPALIVE_MIN_TIME,
- g_param_spec_float ("keepalive-min-time", "Keepalive mimimum time",
+ g_param_spec_float ("keepalive-min-time", "Keepalive minimum time",
"Minimum time to emit keepalive packets (0 disables keepalive packets)",
0.0f, FLT_MAX, DEFAULT_KEEPALIVE_MIN_TIME,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
diff --git a/ext/ladspa/gstladspa.c b/ext/ladspa/gstladspa.c
index 92a6838a0..d19297c2b 100644
--- a/ext/ladspa/gstladspa.c
+++ b/ext/ladspa/gstladspa.c
@@ -103,7 +103,7 @@
* ## Example Sink/Audio/LADSPA line with this plugins
* |[
* gst-launch-1.0 autoaudiosrc ! ladspa-cmt-so-amp-mono gain=2 ! ladspa-caps-so-plate ! ladspa-tap-echo-so-tap-stereo-echo l-delay=500 r-haas-delay=500 ! tee name=myT myT. ! audioconvert ! audioresample ! queue ! ladspasink-cmt-so-null-ai myT. ! audioconvert ! audioresample ! queue ! goom ! videoconvert ! xvimagesink pixel-aspect-ratio=3/4
- * ]| Get audio input, filter it trhough Mono Amplifier, CAPS Plate LADSPA and TAP Stereo Echo, explicitily anulate audio with Null (Audio Output), and play a visualization (recommended hearphones).
+ * ]| Get audio input, filter it trhough Mono Amplifier, CAPS Plate LADSPA and TAP Stereo Echo, explicitly anulate audio with Null (Audio Output), and play a visualization (recommended hearphones).
*
*/
diff --git a/ext/libmms/gstmms.c b/ext/libmms/gstmms.c
index 56243a2b1..18f9ad85f 100644
--- a/ext/libmms/gstmms.c
+++ b/ext/libmms/gstmms.c
@@ -267,8 +267,9 @@ gst_mms_do_seek (GstBaseSrc * src, GstSegment * segment)
return FALSE;
}
start = mmsx_get_current_pos (mmssrc->connection);
- GST_INFO_OBJECT (mmssrc, "sought to %" GST_TIME_FORMAT ", offset after "
- "seek: %" G_GINT64_FORMAT, GST_TIME_ARGS (segment->start), start);
+ GST_INFO_OBJECT (mmssrc,
+ "performed seek to %" GST_TIME_FORMAT ", offset after " "seek: %"
+ G_GINT64_FORMAT, GST_TIME_ARGS (segment->start), start);
} else if (segment->format == GST_FORMAT_BYTES) {
start = mmsx_seek (NULL, mmssrc->connection, segment->start, SEEK_SET);
/* mmsx_seek will close and reopen the connection when seeking with the
@@ -277,7 +278,7 @@ gst_mms_do_seek (GstBaseSrc * src, GstSegment * segment)
GST_DEBUG_OBJECT (mmssrc, "connection broken during seek");
return FALSE;
}
- GST_INFO_OBJECT (mmssrc, "sought to: %" G_GINT64_FORMAT " bytes, "
+ GST_INFO_OBJECT (mmssrc, "performed seek to: %" G_GINT64_FORMAT " bytes, "
"result: %" G_GINT64_FORMAT, segment->start, start);
} else {
GST_DEBUG_OBJECT (mmssrc, "unsupported seek segment format: %s",
diff --git a/ext/lv2/gstlv2filter.c b/ext/lv2/gstlv2filter.c
index 03181e5c9..dcd76c6b1 100644
--- a/ext/lv2/gstlv2filter.c
+++ b/ext/lv2/gstlv2filter.c
@@ -171,7 +171,7 @@ gst_lv2_filter_finalize (GObject * object)
}
#if 0
-/* Convert an LV2 port role to a Gst channel positon
+/* Convert an LV2 port role to a Gst channel position
* WARNING: If the group has only a single port,
* GST_AUDIO_CHANNEL_POSITION_FRONT_CENTER will be returned for pg:centerRole
* (which is used by LV2 for mono groups), but this is not correct. In this
@@ -291,7 +291,7 @@ gst_lv2_filter_setup (GstAudioFilter * gsp, const GstAudioInfo * info)
if (!gst_lv2_setup (&self->lv2, GST_AUDIO_INFO_RATE (info)))
goto no_instance;
- /* FIXME Handle audio channel positionning while negotiating CAPS */
+ /* FIXME Handle audio channel positioning while negotiating CAPS */
#if 0
gint i;
/* set input group pad audio channel position */
diff --git a/ext/lv2/gstlv2utils.c b/ext/lv2/gstlv2utils.c
index 57986812f..7198a7cdf 100644
--- a/ext/lv2/gstlv2utils.c
+++ b/ext/lv2/gstlv2utils.c
@@ -847,7 +847,7 @@ gst_lv2_class_init (GstLV2Class * lv2_class, GType type)
optional_pred);
GstLV2Port desc = { j, GST_LV2_PORT_AUDIO, -1, };
LilvNodes *lv2group = lilv_port_get (lv2plugin, port, group_pred);
- /* FIXME Handle channels positionning
+ /* FIXME Handle channels positioning
* GstAudioChannelPosition position = GST_AUDIO_CHANNEL_POSITION_INVALID; */
if (lv2group) {
@@ -862,7 +862,7 @@ gst_lv2_class_init (GstLV2Class * lv2_class, GType type)
group->ports = g_array_new (FALSE, TRUE, sizeof (GstLV2Port));
}
- /* FIXME Handle channels positionning
+ /* FIXME Handle channels positioning
position = GST_AUDIO_CHANNEL_POSITION_FRONT_LEFT;
sub_values = lilv_port_get_value (lv2plugin, port, designation_pred);
if (lilv_nodes_size (sub_values) > 0) {
diff --git a/ext/mpeg2enc/gstmpeg2enc.cc b/ext/mpeg2enc/gstmpeg2enc.cc
index 9bec3ef07..bdcafe99c 100644
--- a/ext/mpeg2enc/gstmpeg2enc.cc
+++ b/ext/mpeg2enc/gstmpeg2enc.cc
@@ -44,7 +44,7 @@
* In particular, default property values are dependent on the format,
* and can even be forcibly restrained to certain pre-sets (and thereby ignored).
* Note that the (S)VCD profiles also restrict the image size, so some scaling
- * may be needed to accomodate this. The so-called generic profiles (as used
+ * may be needed to accommodate this. The so-called generic profiles (as used
* in the example above) allow most parameters to be adjusted.
*
* |[
diff --git a/ext/mpeg2enc/gstmpeg2encoptions.cc b/ext/mpeg2enc/gstmpeg2encoptions.cc
index b27a70f3d..5cfda38ba 100644
--- a/ext/mpeg2enc/gstmpeg2encoptions.cc
+++ b/ext/mpeg2enc/gstmpeg2encoptions.cc
@@ -375,7 +375,7 @@ GstMpeg2EncOptions::initProperties (GObjectClass * klass)
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
g_object_class_install_property (klass, ARG_UNIT_COEFF_ELIM,
g_param_spec_int ("unit-coeff-elim", "Unit coefficience elimination",
- "How agressively small-unit picture blocks should be skipped",
+ "How aggressively small-unit picture blocks should be skipped",
-40, 40, 0,
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
diff --git a/ext/neon/gstneonhttpsrc.c b/ext/neon/gstneonhttpsrc.c
index a0bf63118..7364cfa5d 100644
--- a/ext/neon/gstneonhttpsrc.c
+++ b/ext/neon/gstneonhttpsrc.c
@@ -298,7 +298,7 @@ gst_neonhttp_src_set_property (GObject * object, guint prop_id,
goto done;
}
if (!gst_neonhttp_src_set_proxy (src, proxy)) {
- GST_WARNING ("badly formated proxy");
+ GST_WARNING ("badly formatted proxy");
goto done;
}
break;
@@ -314,7 +314,7 @@ gst_neonhttp_src_set_property (GObject * object, guint prop_id,
goto done;
}
if (!gst_neonhttp_src_set_location (src, location, NULL)) {
- GST_WARNING ("badly formated location");
+ GST_WARNING ("badly formatted location");
goto done;
}
break;
@@ -429,7 +429,7 @@ gst_neonhttp_src_get_property (GObject * object, guint prop_id,
static void
oom_callback (void)
{
- GST_ERROR ("memory exeception in neon");
+ GST_ERROR ("memory exception in neon");
}
static GstFlowReturn
diff --git a/ext/opencv/MotionCells.cpp b/ext/opencv/MotionCells.cpp
index afa772fc6..85c72286a 100644
--- a/ext/opencv/MotionCells.cpp
+++ b/ext/opencv/MotionCells.cpp
@@ -408,7 +408,7 @@ MotionCells::calculateMotionPercentInCell (int p_row, int p_col,
cntpixelsnum++;
if ((((uchar *) (m_pbwImage.data + m_pbwImage.step[0] * i))[j]) > 0) {
cntmotionpixelnum++;
- if (cntmotionpixelnum >= thresholdmotionpixelnum) { //we dont needs calculate anymore
+ if (cntmotionpixelnum >= thresholdmotionpixelnum) { //we don't need to calculate anymore
*p_motionarea = cntmotionpixelnum;
return (cntmotionpixelnum / cntpixelsnum);
}
diff --git a/ext/opencv/gstcvdilate.cpp b/ext/opencv/gstcvdilate.cpp
index defe2d464..6e450f975 100644
--- a/ext/opencv/gstcvdilate.cpp
+++ b/ext/opencv/gstcvdilate.cpp
@@ -88,7 +88,7 @@ gst_cv_dilate_class_init (GstCvDilateClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstcvdilateerode.cpp b/ext/opencv/gstcvdilateerode.cpp
index 0d8ee3e9c..794783c76 100644
--- a/ext/opencv/gstcvdilateerode.cpp
+++ b/ext/opencv/gstcvdilateerode.cpp
@@ -149,7 +149,7 @@ gst_cv_dilate_erode_class_init (GstCvDilateErodeClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstcverode.cpp b/ext/opencv/gstcverode.cpp
index 28551b004..4569275e2 100644
--- a/ext/opencv/gstcverode.cpp
+++ b/ext/opencv/gstcverode.cpp
@@ -88,7 +88,7 @@ gst_cv_erode_class_init (GstCvErodeClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstcvsmooth.cpp b/ext/opencv/gstcvsmooth.cpp
index 02c995d5d..0e22db69a 100644
--- a/ext/opencv/gstcvsmooth.cpp
+++ b/ext/opencv/gstcvsmooth.cpp
@@ -237,7 +237,7 @@ gst_cv_smooth_class_init (GstCvSmoothClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstdewarp.cpp b/ext/opencv/gstdewarp.cpp
index 3c123c573..15860c26a 100644
--- a/ext/opencv/gstdewarp.cpp
+++ b/ext/opencv/gstdewarp.cpp
@@ -90,9 +90,9 @@ dewarp_display_mode_get_type (void)
static GType dewarp_display_mode_type = 0;
static const GEnumValue dewarp_display_mode[] = {
{GST_DEWARP_DISPLAY_PANORAMA, "Single panorama image", "single-panorama"},
- {GST_DEWARP_DISPLAY_DOUBLE_PANORAMA, "Dewarped image is splitted in two "
+ {GST_DEWARP_DISPLAY_DOUBLE_PANORAMA, "Dewarped image is split in two "
"images displayed one below the other", "double-panorama"},
- {GST_DEWARP_DISPLAY_QUAD_VIEW, "Dewarped image is splitted in four images "
+ {GST_DEWARP_DISPLAY_QUAD_VIEW, "Dewarped image is split in four images "
"dysplayed as a quad view",
"quad-view"},
{0, NULL, NULL},
@@ -301,7 +301,7 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
filter->x_center = v;
filter->need_map_update = TRUE;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "x center setted to %f", filter->x_center);
+ GST_LOG_OBJECT (filter, "x center set to %f", filter->x_center);
}
break;
case PROP_Y_CENTER:
@@ -310,7 +310,7 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
filter->y_center = v;
filter->need_map_update = TRUE;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "y center setted to %f", filter->y_center);
+ GST_LOG_OBJECT (filter, "y center set to %f", filter->y_center);
}
break;
case PROP_INNER_RADIUS:
@@ -319,7 +319,7 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
filter->inner_radius = v;
filter->need_map_update = TRUE;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "inner radius setted to %f",
+ GST_LOG_OBJECT (filter, "inner radius set to %f",
filter->inner_radius);
}
break;
@@ -329,7 +329,7 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
filter->outer_radius = v;
filter->need_map_update = TRUE;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "outer radius setted to %f",
+ GST_LOG_OBJECT (filter, "outer radius set to %f",
filter->outer_radius);
}
break;
@@ -339,7 +339,7 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
filter->remap_correction_x = v;
filter->need_map_update = TRUE;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "x remap correction setted to %f",
+ GST_LOG_OBJECT (filter, "x remap correction set to %f",
filter->remap_correction_x);
}
break;
@@ -349,13 +349,13 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
filter->remap_correction_y = v;
filter->need_map_update = TRUE;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "y remap correction setted to %f",
+ GST_LOG_OBJECT (filter, "y remap correction set to %f",
filter->remap_correction_y);
}
break;
case PROP_INTERPOLATION_MODE:
filter->interpolation_mode = g_value_get_enum (value);
- GST_LOG_OBJECT (filter, "interpolation mode setted to %" G_GINT32_FORMAT,
+ GST_LOG_OBJECT (filter, "interpolation mode set to %" G_GINT32_FORMAT,
filter->interpolation_mode);
break;
case PROP_DISPLAY_MODE:
@@ -363,7 +363,7 @@ gst_dewarp_set_property (GObject * object, guint prop_id,
if (disp_mode != filter->display_mode) {
filter->display_mode = disp_mode;
need_reconfigure = TRUE;
- GST_LOG_OBJECT (filter, "display mode setted to %" G_GINT32_FORMAT,
+ GST_LOG_OBJECT (filter, "display mode set to %" G_GINT32_FORMAT,
filter->display_mode);
}
break;
@@ -510,7 +510,7 @@ gst_dewarp_calculate_dimensions (GstDewarp * filter, GstPadDirection direction,
}
/* if outer_radius and inner radius are very close then width and height
- could be 0, we assume passtrough in this case
+ could be 0, we assume passthrough in this case
*/
if (G_UNLIKELY (*out_width == 0) || G_UNLIKELY (*out_height == 0)) {
GST_WARNING_OBJECT (filter,
diff --git a/ext/opencv/gstdisparity.cpp b/ext/opencv/gstdisparity.cpp
index e584c26c6..212bcb829 100644
--- a/ext/opencv/gstdisparity.cpp
+++ b/ext/opencv/gstdisparity.cpp
@@ -370,7 +370,7 @@ gst_disparity_handle_sink_event (GstPad * pad,
GST_INFO_OBJECT (pad, " Negotiating caps via event %" GST_PTR_FORMAT,
caps);
if (!gst_pad_has_current_caps (fs->srcpad)) {
- /* Init image info (widht, height, etc) and all OpenCV matrices */
+ /* Init image info (width, height, etc) and all OpenCV matrices */
initialise_disparity (fs, info.width, info.height,
info.finfo->n_components);
diff --git a/ext/opencv/gstedgedetect.cpp b/ext/opencv/gstedgedetect.cpp
index 04a4681ba..9ef4e10c6 100644
--- a/ext/opencv/gstedgedetect.cpp
+++ b/ext/opencv/gstedgedetect.cpp
@@ -169,7 +169,7 @@ gst_edge_detect_class_init (GstEdgeDetectClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstfaceblur.cpp b/ext/opencv/gstfaceblur.cpp
index 7de576dcd..0dd4df6be 100644
--- a/ext/opencv/gstfaceblur.cpp
+++ b/ext/opencv/gstfaceblur.cpp
@@ -210,7 +210,7 @@ gst_face_blur_class_init (GstFaceBlurClass * klass)
DEFAULT_SCALE_FACTOR,
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
g_object_class_install_property (gobject_class, PROP_MIN_NEIGHBORS,
- g_param_spec_int ("min-neighbors", "Mininum neighbors",
+ g_param_spec_int ("min-neighbors", "Minimum neighbors",
"Minimum number (minus 1) of neighbor rectangles that makes up "
"an object", 0, G_MAXINT, DEFAULT_MIN_NEIGHBORS,
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
@@ -235,7 +235,7 @@ gst_face_blur_class_init (GstFaceBlurClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstfacedetect.cpp b/ext/opencv/gstfacedetect.cpp
index e6a32df39..0ef4c32d2 100644
--- a/ext/opencv/gstfacedetect.cpp
+++ b/ext/opencv/gstfacedetect.cpp
@@ -320,7 +320,7 @@ gst_face_detect_class_init (GstFaceDetectClass * klass)
1.1, 10.0, DEFAULT_SCALE_FACTOR,
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
g_object_class_install_property (gobject_class, PROP_MIN_NEIGHBORS,
- g_param_spec_int ("min-neighbors", "Mininum neighbors",
+ g_param_spec_int ("min-neighbors", "Minimum neighbors",
"Minimum number (minus 1) of neighbor rectangles that makes up "
"an object", 0, G_MAXINT, DEFAULT_MIN_NEIGHBORS,
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
diff --git a/ext/opencv/gstgrabcut.cpp b/ext/opencv/gstgrabcut.cpp
index 4c32c1029..1c0b8fecd 100644
--- a/ext/opencv/gstgrabcut.cpp
+++ b/ext/opencv/gstgrabcut.cpp
@@ -203,7 +203,7 @@ IF nothing is present, then nothing is done.", "Miguel Casas-Sanchez <miguelecas
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gstretinex.cpp b/ext/opencv/gstretinex.cpp
index 84706f04a..48e8bfda5 100644
--- a/ext/opencv/gstretinex.cpp
+++ b/ext/opencv/gstretinex.cpp
@@ -161,7 +161,7 @@ gst_retinex_class_init (GstRetinexClass * klass)
(GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
gst_element_class_set_static_metadata (element_class,
- "Retinex image colour enhacement", "Filter/Effect/Video",
+ "Retinex image colour enhancement", "Filter/Effect/Video",
"Multiscale retinex for colour image enhancement",
"Miguel Casas-Sanchez <miguelecasassanchez@gmail.com>");
@@ -171,7 +171,7 @@ gst_retinex_class_init (GstRetinexClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
@@ -277,7 +277,7 @@ gst_retinex_transform_ip (GstOpencvVideoFilter * filter, GstBuffer * buf,
img.convertTo (retinex->cvA, retinex->cvA.type ());
log (retinex->cvA, retinex->cvB);
- /* Compute log of blured image */
+ /* Compute log of blurred image */
filter_size = (int) floor (sigma * 6) / 2;
filter_size = filter_size * 2 + 1;
@@ -294,7 +294,7 @@ gst_retinex_transform_ip (GstOpencvVideoFilter * filter, GstBuffer * buf,
}
/* Multiscale retinex restoration. The image and a set of filtered images are
converted to the log domain and subtracted from the original with some set
- of weights. Typicaly called with three equally weighted scales of fine,
+ of weights. Typically called with three equally weighted scales of fine,
medium and wide standard deviations.
O = Log(I) - sum_i [ wi * Log(H(I)) ]
where O is the output, H is a gaussian 2d filter and I is the input image
diff --git a/ext/opencv/gstskindetect.cpp b/ext/opencv/gstskindetect.cpp
index 60d0697be..105e83495 100644
--- a/ext/opencv/gstskindetect.cpp
+++ b/ext/opencv/gstskindetect.cpp
@@ -168,7 +168,7 @@ gst_skin_detect_class_init (GstSkinDetectClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/opencv/gsttextoverlay.cpp b/ext/opencv/gsttextoverlay.cpp
index b8e2be300..950087b64 100644
--- a/ext/opencv/gsttextoverlay.cpp
+++ b/ext/opencv/gsttextoverlay.cpp
@@ -217,7 +217,7 @@ gst_opencv_text_overlay_class_init (GstOpencvTextOverlayClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/resindvd/gstmpegdemux.c b/ext/resindvd/gstmpegdemux.c
index a35a6a411..02ce48a53 100644
--- a/ext/resindvd/gstmpegdemux.c
+++ b/ext/resindvd/gstmpegdemux.c
@@ -2087,7 +2087,7 @@ gst_flups_demux_is_pes_sync (guint32 sync)
((sync & 0xe0) == 0xc0) || ((sync & 0xf0) == 0xe0);
}
-/* If we can pull that's prefered */
+/* If we can pull that's preferred */
static gboolean
gst_flups_demux_sink_activate (GstPad * sinkpad, GstObject * parent)
{
diff --git a/ext/resindvd/resindvdsrc.c b/ext/resindvd/resindvdsrc.c
index f18816019..b4b8f9258 100644
--- a/ext/resindvd/resindvdsrc.c
+++ b/ext/resindvd/resindvdsrc.c
@@ -2827,7 +2827,7 @@ rsn_dvdsrc_do_seek (GstBaseSrc * bsrc, GstSegment * segment)
gboolean ret = FALSE;
if (segment->format == rsndvd_format || src->first_seek) {
- /* The internal format has alread served its purpose of waking
+ /* The internal format has already served its purpose of waking
* everything up and flushing, we just need to step to the next
* data block (below) so we know our new position */
ret = TRUE;
diff --git a/ext/resindvd/rsninputselector.c b/ext/resindvd/rsninputselector.c
index 4542edec3..debee91ec 100644
--- a/ext/resindvd/rsninputselector.c
+++ b/ext/resindvd/rsninputselector.c
@@ -1201,7 +1201,7 @@ gst_input_selector_class_init (RsnInputSelectorClass * klass)
*
* The active pad may push more buffers than what is currently displayed/consumed
* and when changing pads those buffers will be discarded and the only way to
- * reactivate that pad without loosing the already consumed buffers is to enable cache.
+ * reactivate that pad without losing the already consumed buffers is to enable cache.
*/
g_object_class_install_property (gobject_class, PROP_CACHE_BUFFERS,
g_param_spec_boolean ("cache-buffers", "Cache Buffers",
diff --git a/ext/rtmp/gstrtmpsrc.c b/ext/rtmp/gstrtmpsrc.c
index 0ad97abef..1db02e278 100644
--- a/ext/rtmp/gstrtmpsrc.c
+++ b/ext/rtmp/gstrtmpsrc.c
@@ -579,7 +579,7 @@ success:
/* This is set here so that the call to create() above doesn't clear it */
src->discont = TRUE;
- GST_DEBUG_OBJECT (src, "Seek to %" GST_TIME_FORMAT " successfull",
+ GST_DEBUG_OBJECT (src, "Seek to %" GST_TIME_FORMAT " successful",
GST_TIME_ARGS (segment->start));
return TRUE;
diff --git a/ext/soundtouch/gstpitch.cc b/ext/soundtouch/gstpitch.cc
index 89bab3f07..9ab0d1d7f 100644
--- a/ext/soundtouch/gstpitch.cc
+++ b/ext/soundtouch/gstpitch.cc
@@ -669,7 +669,7 @@ gst_pitch_src_query (GstPad * pad, GstObject * parent, GstQuery * query)
/* this function returns FALSE if not enough data is known to transform the
* segment into proper downstream values. If the function does return false
* the segment should be stalled until enough information is available.
- * If the funtion returns TRUE, event will be replaced by the new downstream
+ * If the function returns TRUE, event will be replaced by the new downstream
* compatible event.
*/
static gboolean
diff --git a/ext/spandsp/gstdtmfdetect.c b/ext/spandsp/gstdtmfdetect.c
index df7fc7ef1..6adf37153 100644
--- a/ext/spandsp/gstdtmfdetect.c
+++ b/ext/spandsp/gstdtmfdetect.c
@@ -34,7 +34,7 @@
* * gint `type` (0-1): The application uses this field to specify which of the two methods
* specified in RFC 2833 to use. The value should be 0 for tones and 1 for
* named events. Tones are specified by their frequencies and events are
- * specfied by their number. This element can only take events as input.
+ * specified by their number. This element can only take events as input.
* Do not confuse with "method" which specified the output.
* * gint `number` (0-16): The event number.
* * gint `method` (2): This field will always been 2 (ie sound) from this element.
diff --git a/ext/spandsp/gsttonegeneratesrc.c b/ext/spandsp/gsttonegeneratesrc.c
index c80679927..341aeab5a 100644
--- a/ext/spandsp/gsttonegeneratesrc.c
+++ b/ext/spandsp/gsttonegeneratesrc.c
@@ -139,7 +139,7 @@ gst_tone_generate_src_class_init (GstToneGenerateSrcClass * klass)
g_object_class_install_property (gobject_class, PROP_REPEAT,
g_param_spec_boolean ("repeat", "Repeat the specified tone period ",
- "Whether to repeat specified tone indefinitly", DEFAULT_REPEAT,
+ "Whether to repeat specified tone indefinitely", DEFAULT_REPEAT,
G_PARAM_READWRITE));
gst_element_class_add_static_pad_template (gstelement_class,
diff --git a/ext/srt/gstsrtobject.c b/ext/srt/gstsrtobject.c
index cbc3cfd5f..4ae8a4dc9 100644
--- a/ext/srt/gstsrtobject.c
+++ b/ext/srt/gstsrtobject.c
@@ -429,7 +429,7 @@ gst_srt_object_install_properties_helper (GObjectClass * gobject_class)
*/
g_object_class_install_property (gobject_class, PROP_POLL_TIMEOUT,
g_param_spec_int ("poll-timeout", "Poll timeout",
- "Return poll wait after timeout miliseconds (-1 = infinite)", -1,
+ "Return poll wait after timeout milliseconds (-1 = infinite)", -1,
G_MAXINT32, GST_SRT_DEFAULT_POLL_TIMEOUT,
G_PARAM_READWRITE | GST_PARAM_MUTABLE_READY |
G_PARAM_STATIC_STRINGS));
diff --git a/ext/srtp/gstsrtpdec.c b/ext/srtp/gstsrtpdec.c
index 47ebfae0b..33880bc9e 100644
--- a/ext/srtp/gstsrtpdec.c
+++ b/ext/srtp/gstsrtpdec.c
@@ -292,7 +292,7 @@ gst_srtp_dec_class_init (GstSrtpDecClass * klass)
* @gstsrtpdec: the element on which the signal is emitted
* @ssrc: The unique SSRC of the stream
*
- * Signal emited to get the parameters relevant to stream
+ * Signal emitted to get the parameters relevant to stream
* with @ssrc. User should provide the key and the RTP and
* RTCP encryption ciphers and authentication, and return
* them wrapped in a GstCaps.
@@ -318,7 +318,7 @@ gst_srtp_dec_class_init (GstSrtpDecClass * klass)
* @gstsrtpdec: the element on which the signal is emitted
* @ssrc: The unique SSRC of the stream
*
- * Signal emited when the stream with @ssrc has reached the
+ * Signal emitted when the stream with @ssrc has reached the
* soft limit of utilisation of it's master encryption key.
* User should provide a new key and new RTP and RTCP encryption
* ciphers and authentication, and return them wrapped in a
@@ -333,7 +333,7 @@ gst_srtp_dec_class_init (GstSrtpDecClass * klass)
* @gstsrtpdec: the element on which the signal is emitted
* @ssrc: The unique SSRC of the stream
*
- * Signal emited when the stream with @ssrc has reached the
+ * Signal emitted when the stream with @ssrc has reached the
* hard limit of utilisation of it's master encryption key.
* User should provide a new key and new RTP and RTCP encryption
* ciphers and authentication, and return them wrapped in a
@@ -361,7 +361,7 @@ gst_srtp_dec_class_init (GstSrtpDecClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/ext/srtp/gstsrtpenc.c b/ext/srtp/gstsrtpenc.c
index ae6b450ab..d677afcce 100644
--- a/ext/srtp/gstsrtpenc.c
+++ b/ext/srtp/gstsrtpenc.c
@@ -56,7 +56,7 @@
* An application can request multiple RTP and RTCP pads to protect,
* but every sink pad requested must receive packets from the same
* source (identical SSRC). If a packet received contains a different
- * SSRC, a warning is emited and the valid SSRC is forced on the packet.
+ * SSRC, a warning is emitted and the valid SSRC is forced on the packet.
*
* This element uses libsrtp library. When receiving the first packet,
* the library is initialized with a new stream (based on the SSRC). It
@@ -335,7 +335,7 @@ gst_srtp_enc_class_init (GstSrtpEncClass * klass)
* GstSrtpEnc::soft-limit:
* @gstsrtpenc: the element on which the signal is emitted
*
- * Signal emited when the stream with @ssrc has reached the soft
+ * Signal emitted when the stream with @ssrc has reached the soft
* limit of utilisation of it's master encryption key. User should
* provide a new key by setting the #GstSrtpEnc:key property.
*/
@@ -484,7 +484,7 @@ done:
return ret;
}
-/* Release ressources and set default values
+/* Release resources and set default values
*/
static void
gst_srtp_enc_reset_no_lock (GstSrtpEnc * filter)
diff --git a/ext/ttml/subtitle.h b/ext/ttml/subtitle.h
index cf67fd4ef..c0a1641b2 100644
--- a/ext/ttml/subtitle.h
+++ b/ext/ttml/subtitle.h
@@ -127,7 +127,7 @@ struct _GstSubtitleColor {
* @GST_SUBTITLE_TEXT_DIRECTION_RTL: Text direction is right-to-left.
*
* Defines the progression direction of unicode text that is being treated by
- * the unicode bidirectional algorithm as embedded or overidden (see
+ * the unicode bidirectional algorithm as embedded or overridden (see
* http://unicode.org/reports/tr9/ for more details of the unicode
* bidirectional algorithm).
*/
@@ -269,7 +269,7 @@ typedef enum {
/**
* GstSubtitleStyleSet:
* @text_direction: Defines the direction of text that has been declared by the
- * #GstSubtitleStyleSet:unicode_bidi attribute to be embbedded or overridden.
+ * #GstSubtitleStyleSet:unicode_bidi attribute to be embedded or overridden.
* Applies to both #GstSubtitleBlocks and #GstSubtitleElements.
* @font_family: The name of the font family that should be used to render the
* text of an inline element. Applies only to #GstSubtitleElements.
diff --git a/ext/ttml/ttmlparse.c b/ext/ttml/ttmlparse.c
index e097644fb..102ac26de 100644
--- a/ext/ttml/ttmlparse.c
+++ b/ext/ttml/ttmlparse.c
@@ -1297,7 +1297,7 @@ ttml_handle_element_whitespace (GNode * node, gpointer data)
gunichar u = g_utf8_get_char (c);
gint nbytes = g_unichar_to_utf8 (u, buf);
- /* Repace each newline or tab with a space. */
+ /* Replace each newline or tab with a space. */
if (nbytes == 1 && (buf[0] == TTML_CHAR_LF || buf[0] == TTML_CHAR_TAB)) {
*c = ' ';
buf[0] = TTML_CHAR_SPACE;
diff --git a/ext/vulkan/vkdownload.c b/ext/vulkan/vkdownload.c
index fa9fa4902..13b41b78c 100644
--- a/ext/vulkan/vkdownload.c
+++ b/ext/vulkan/vkdownload.c
@@ -634,7 +634,7 @@ gst_vulkan_download_change_state (GstElement * element,
if (!gst_vulkan_ensure_element_data (element, NULL,
&vk_download->instance)) {
GST_ELEMENT_ERROR (vk_download, RESOURCE, NOT_FOUND,
- ("Failed to retreive vulkan instance"), (NULL));
+ ("Failed to retrieve vulkan instance"), (NULL));
return GST_STATE_CHANGE_FAILURE;
}
if (!gst_vulkan_device_run_context_query (GST_ELEMENT (vk_download),
diff --git a/ext/vulkan/vkfullscreenrender.c b/ext/vulkan/vkfullscreenrender.c
index b627e943b..5de6a1bd2 100644
--- a/ext/vulkan/vkfullscreenrender.c
+++ b/ext/vulkan/vkfullscreenrender.c
@@ -729,7 +729,7 @@ gst_vulkan_full_screen_render_start (GstBaseTransform * bt)
if (!gst_vulkan_ensure_element_data (GST_ELEMENT (bt), NULL,
&render->instance)) {
GST_ELEMENT_ERROR (render, RESOURCE, NOT_FOUND,
- ("Failed to retreive vulkan instance"), (NULL));
+ ("Failed to retrieve vulkan instance"), (NULL));
return FALSE;
}
if (!gst_vulkan_device_run_context_query (GST_ELEMENT (render),
diff --git a/ext/vulkan/vkshader.c b/ext/vulkan/vkshader.c
index e444e7fa9..dc9cff715 100644
--- a/ext/vulkan/vkshader.c
+++ b/ext/vulkan/vkshader.c
@@ -53,11 +53,11 @@ _vk_create_shader (GstVulkanDevice * device, gchar * code, gsize size,
g_return_val_if_fail (first_word == SPIRV_MAGIC_NUMBER_NE
|| first_word == SPIRV_MAGIC_NUMBER_OE, NULL);
if (first_word == SPIRV_MAGIC_NUMBER_OE) {
- /* endianess swap... */
+ /* endianness swap... */
guint32 *old_code = (guint32 *) code;
gsize i;
- GST_DEBUG ("performaing endianess conversion on spirv shader of size %"
+ GST_DEBUG ("performaing endianness conversion on spirv shader of size %"
G_GSIZE_FORMAT, size);
new_code = g_new0 (guint32, size / 4);
diff --git a/ext/vulkan/vkupload.c b/ext/vulkan/vkupload.c
index 7b1b3b1eb..c0f220f30 100644
--- a/ext/vulkan/vkupload.c
+++ b/ext/vulkan/vkupload.c
@@ -1352,7 +1352,7 @@ gst_vulkan_upload_change_state (GstElement * element, GstStateChange transition)
case GST_STATE_CHANGE_READY_TO_PAUSED:
if (!gst_vulkan_ensure_element_data (element, NULL, &vk_upload->instance)) {
GST_ELEMENT_ERROR (vk_upload, RESOURCE, NOT_FOUND,
- ("Failed to retreive vulkan instance"), (NULL));
+ ("Failed to retrieve vulkan instance"), (NULL));
return GST_STATE_CHANGE_FAILURE;
}
if (!gst_vulkan_device_run_context_query (GST_ELEMENT (vk_upload),
diff --git a/ext/vulkan/vkviewconvert.c b/ext/vulkan/vkviewconvert.c
index da46b8838..2e60285f6 100644
--- a/ext/vulkan/vkviewconvert.c
+++ b/ext/vulkan/vkviewconvert.c
@@ -1604,7 +1604,7 @@ fixate_size (GstVulkanViewConvert * viewconvert,
goto done;
}
- /* If all this failed, keep the height that was nearest to the orignal
+ /* If all this failed, keep the height that was nearest to the original
* height and the nearest possible width. This changes the DAR but
* there's not much else to do here.
*/
diff --git a/ext/wayland/gstwaylandsink.c b/ext/wayland/gstwaylandsink.c
index bab57fd97..9e0d4d4b9 100644
--- a/ext/wayland/gstwaylandsink.c
+++ b/ext/wayland/gstwaylandsink.c
@@ -795,7 +795,7 @@ gst_wayland_sink_show_frame (GstVideoSink * vsink, GstBuffer * buffer)
gst_buffer_pool_config_set_params (config, caps, sink->video_info.size,
2, 0);
- /* This is a video pool, it should not fail with basic setings */
+ /* This is a video pool, it should not fail with basic settings */
if (!gst_buffer_pool_set_config (sink->pool, config) ||
!gst_buffer_pool_set_active (sink->pool, TRUE))
goto activate_failed;
diff --git a/ext/wayland/wlbuffer.c b/ext/wayland/wlbuffer.c
index 21214604f..74d62162f 100644
--- a/ext/wayland/wlbuffer.c
+++ b/ext/wayland/wlbuffer.c
@@ -57,7 +57,7 @@
* holds a reference to the GstWlBuffer, but without having an actual reference.
* When we kill the display, there is no way for the GstWlBuffer, the associated
* GstBuffer and the GstBufferPool to get destroyed, so we are going to leak a
- * fair ammount of memory.
+ * fair amount of memory.
*
* Normally, this rarely happens, because the compositor releases buffers
* almost immediately and when waylandsink stops, they are already released.
diff --git a/ext/webp/gstwebpdec.c b/ext/webp/gstwebpdec.c
index 85bb5bf36..2b9c2466e 100644
--- a/ext/webp/gstwebpdec.c
+++ b/ext/webp/gstwebpdec.c
@@ -380,7 +380,7 @@ gst_webp_dec_update_src_caps (GstWebPDec * dec, GstMapInfo * map_info)
if (features.width < MIN_WIDTH || features.width > MAX_WIDTH
|| features.height < MIN_HEIGHT || features.height > MAX_HEIGHT) {
- GST_ERROR_OBJECT (dec, "Dimensions of the frame is unspported by libwebp");
+ GST_ERROR_OBJECT (dec, "Dimensions of the frame is unsupported by libwebp");
return GST_FLOW_ERROR;
}
diff --git a/ext/webrtc/gstwebrtcbin.c b/ext/webrtc/gstwebrtcbin.c
index 5e101deae..bd9cd0908 100644
--- a/ext/webrtc/gstwebrtcbin.c
+++ b/ext/webrtc/gstwebrtcbin.c
@@ -87,7 +87,7 @@
* balanced bundle policy
* setting custom DTLS certificates
*
- * seperate session id's from mlineindex properly
+ * separate session id's from mlineindex properly
* how to deal with replacing a input/output track/stream
*/
@@ -1411,7 +1411,7 @@ _find_codec_preferences (GstWebRTCBin * webrtc,
WebRTCTransceiver *trans = (WebRTCTransceiver *) rtp_trans;
GstCaps *ret = NULL;
- GST_LOG_OBJECT (webrtc, "retreiving codec preferences from %" GST_PTR_FORMAT,
+ GST_LOG_OBJECT (webrtc, "retrieving codec preferences from %" GST_PTR_FORMAT,
trans);
if (rtp_trans && rtp_trans->codec_preferences) {
@@ -1481,7 +1481,7 @@ _add_supported_attributes_to_caps (GstWebRTCBin * webrtc,
/*if (!gst_structure_has_field (s, "rtcp-fb-transport-cc"))
gst_structure_set (s, "rtcp-fb-nack-pli", G_TYPE_BOOLEAN, TRUE, NULL); */
- /* FIXME: codec-specific paramters? */
+ /* FIXME: codec-specific parameters? */
}
return ret;
@@ -5715,7 +5715,7 @@ gst_webrtc_bin_class_init (GstWebRTCBinClass * klass)
* and is constantly changing these statistics may be changed to fit with
* the latest spec.
*
- * Each field key is a unique identifer for each RTCStats
+ * Each field key is a unique identifier for each RTCStats
* (https://www.w3.org/TR/webrtc/#rtcstats-dictionary) value (another
* GstStructure) in the RTCStatsReport
* (https://www.w3.org/TR/webrtc/#rtcstatsreport-object). Each supported
@@ -5884,11 +5884,11 @@ gst_webrtc_bin_class_init (GstWebRTCBinClass * klass)
* members outlined https://www.w3.org/TR/webrtc/#dom-rtcdatachannelinit and
* and reproduced below
*
- * ordered G_TYPE_BOOLEAN Whether the channal will send data with guarenteed ordering
+ * ordered G_TYPE_BOOLEAN Whether the channal will send data with guaranteed ordering
* max-packet-lifetime G_TYPE_INT The time in milliseconds to attempt transmitting unacknowledged data. -1 for unset
* max-retransmits G_TYPE_INT The number of times data will be attempted to be transmitted without acknowledgement before dropping
* protocol G_TYPE_STRING The subprotocol used by this channel
- * negotiated G_TYPE_BOOLEAN Whether the created data channel should not perform in-band chnanel announcment. If %TRUE, then application must negotiate the channel itself and create the corresponding channel on the peer with the same id.
+ * negotiated G_TYPE_BOOLEAN Whether the created data channel should not perform in-band chnanel announcement. If %TRUE, then application must negotiate the channel itself and create the corresponding channel on the peer with the same id.
* id G_TYPE_INT Override the default identifier selection of this channel
* priority GST_TYPE_WEBRTC_PRIORITY_TYPE The priority to use for this channel
*
diff --git a/ext/webrtc/transportreceivebin.c b/ext/webrtc/transportreceivebin.c
index d059fa270..667fae634 100644
--- a/ext/webrtc/transportreceivebin.c
+++ b/ext/webrtc/transportreceivebin.c
@@ -440,7 +440,7 @@ transport_receive_bin_class_init (TransportReceiveBinClass * klass)
g_object_class_install_property (gobject_class,
PROP_STREAM,
g_param_spec_object ("stream", "Stream",
- "The TransportStream for this receiveing bin",
+ "The TransportStream for this receiving bin",
transport_stream_get_type (),
G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
}
diff --git a/ext/webrtc/webrtcsdp.c b/ext/webrtc/webrtcsdp.c
index 42d650f7b..c6cdf0414 100644
--- a/ext/webrtc/webrtcsdp.c
+++ b/ext/webrtc/webrtcsdp.c
@@ -319,7 +319,7 @@ validate_sdp (GstWebRTCSignalingState state, SDPSource source,
}
if (!_media_has_setup (media, i, error))
goto fail;
- /* check paramaters in bundle are the same */
+ /* check parameters in bundle are the same */
if (media_in_bundle) {
const gchar *ice_ufrag =
gst_sdp_media_get_attribute_val (media, "ice-ufrag");
diff --git a/ext/webrtcdsp/gstwebrtcdsp.cpp b/ext/webrtcdsp/gstwebrtcdsp.cpp
index 9d7c8d2a3..4f097e0e5 100644
--- a/ext/webrtcdsp/gstwebrtcdsp.cpp
+++ b/ext/webrtcdsp/gstwebrtcdsp.cpp
@@ -40,13 +40,13 @@
* a single probe and DSP.
*
* The probe can only be used within the same top level GstPipeline.
- * Additonally, to simplify the code, the probe element must be created
+ * Additionally, to simplify the code, the probe element must be created
* before the DSP sink pad is activated. It does not need to be in any
* particular state and does not even need to be added to the pipeline yet.
*
* # Example launch line
*
- * As a conveniance, the echo canceller can be tested using an echo loop. In
+ * As a convenience, the echo canceller can be tested using an echo loop. In
* this configuration, one would expect a single echo to be heard.
*
* |[
@@ -279,7 +279,7 @@ G_DEFINE_TYPE (GstWebrtcDsp, gst_webrtc_dsp, GST_TYPE_AUDIO_FILTER);
static const gchar *
webrtc_error_to_string (gint err)
{
- const gchar *str = "unkown error";
+ const gchar *str = "unknown error";
switch (err) {
case webrtc::AudioProcessing::kNoError:
diff --git a/ext/webrtcdsp/gstwebrtcechoprobe.cpp b/ext/webrtcdsp/gstwebrtcechoprobe.cpp
index ad350e78b..a5095be74 100644
--- a/ext/webrtcdsp/gstwebrtcechoprobe.cpp
+++ b/ext/webrtcdsp/gstwebrtcechoprobe.cpp
@@ -259,7 +259,7 @@ gst_webrtc_echo_probe_class_init (GstWebrtcEchoProbeClass * klass)
&gst_webrtc_echo_probe_sink_template);
gst_element_class_set_static_metadata (element_class,
- "Accoustic Echo Canceller probe",
+ "Acoustic Echo Canceller probe",
"Generic/Audio",
"Gathers playback buffers for webrtcdsp",
"Nicolas Dufresne <nicolas.dufrsesne@collabora.com>");
diff --git a/ext/webrtcdsp/gstwebrtcechoprobe.h b/ext/webrtcdsp/gstwebrtcechoprobe.h
index ea7f72140..29f0eb4ca 100644
--- a/ext/webrtcdsp/gstwebrtcechoprobe.h
+++ b/ext/webrtcdsp/gstwebrtcechoprobe.h
@@ -61,7 +61,7 @@ struct _GstWebrtcEchoProbe
* object lock and also lock the probe. The natural order for the DSP is
* to lock the DSP and then the echo probe. If we where using the probe
* object lock, we'd be racing with GstBin which will lock sink to src,
- * and may accidently reverse the order. */
+ * and may accidentally reverse the order. */
GMutex lock;
/* Protected by the lock */
diff --git a/ext/wildmidi/gstwildmididec.c b/ext/wildmidi/gstwildmididec.c
index 60ae3b3de..d628c0fe6 100644
--- a/ext/wildmidi/gstwildmididec.c
+++ b/ext/wildmidi/gstwildmididec.c
@@ -628,7 +628,7 @@ gst_wildmidi_dec_decode (GstNonstreamAudioDecoder * dec, GstBuffer ** buffer,
return FALSE;
/* Allocate output buffer
- * Multiply by 2 to accomodate for the sample size (16 bit = 2 byte) */
+ * Multiply by 2 to accommodate for the sample size (16 bit = 2 byte) */
outbuf_size = wildmidi_dec->output_buffer_size * 2 * WILDMIDI_NUM_CHANNELS;
outbuf =
gst_nonstream_audio_decoder_allocate_output_buffer (dec, outbuf_size);
diff --git a/ext/wpe/gstwpesrc.cpp b/ext/wpe/gstwpesrc.cpp
index 98ade7fa3..09cb77fe7 100644
--- a/ext/wpe/gstwpesrc.cpp
+++ b/ext/wpe/gstwpesrc.cpp
@@ -338,7 +338,7 @@ gst_wpe_src_event (GstPad * pad, GstObject * parent, GstEvent * event)
case GST_NAVIGATION_EVENT_KEY_RELEASE:
if (gst_navigation_event_parse_key_event (event, &key)) {
/* FIXME: This is wrong... The GstNavigation API should pass
- hardware-level informations, not high-level keysym strings */
+ hardware-level information, not high-level keysym strings */
uint32_t keysym =
(uint32_t) xkb_keysym_from_name (key, XKB_KEYSYM_NO_FLAGS);
struct wpe_input_keyboard_event wpe_event;
diff --git a/ext/x265/gstx265enc.c b/ext/x265/gstx265enc.c
index 83088b4ea..724241891 100644
--- a/ext/x265/gstx265enc.c
+++ b/ext/x265/gstx265enc.c
@@ -923,7 +923,7 @@ gst_x265_enc_init_encoder (GstX265Enc * encoder)
}
if (i == encoder->peer_profiles->len) {
- GST_ERROR_OBJECT (encoder, "Could't apply peer profile");
+ GST_ERROR_OBJECT (encoder, "Couldn't apply peer profile");
GST_OBJECT_UNLOCK (encoder);
return FALSE;
@@ -1191,7 +1191,7 @@ gst_x265_enc_get_header_buffer (GstX265Enc * encoder)
GST_DEBUG_OBJECT (encoder, "%d nal units in header", i_nal);
/* x265 returns also non header nal units with the call x265_encoder_headers.
- * The usefull headers are sequential (VPS, SPS and PPS), so we look for this
+ * The useful headers are sequential (VPS, SPS and PPS), so we look for this
* nal units and only copy these tree nal units as the header */
vps_idx = sps_idx = pps_idx = -1;
diff --git a/ext/zbar/gstzbar.c b/ext/zbar/gstzbar.c
index 6591d1968..91caf9ebf 100644
--- a/ext/zbar/gstzbar.c
+++ b/ext/zbar/gstzbar.c
@@ -26,11 +26,11 @@
* If the .#GstZBar:attach-frame property is %TRUE, the posted barcode message
* includes a sample of the frame where the barcode was detected (Since 1.6).
*
- * The element generate messages named`barcode`. The structure containes these fields:
+ * The element generate messages named`barcode`. The structure contains these fields:
*
* * #GstClockTime `timestamp`: the timestamp of the buffer that triggered the message.
* * gchar * `type`: the symbol type.
- * * gchar * `symbol`: the deteted bar code data.
+ * * gchar * `symbol`: the detected bar code data.
* * gint `quality`: an unscaled, relative quantity: larger values are better than smaller
* values.
* * GstSample `frame`: the frame in which the barcode message was detected, if
diff --git a/ext/opencv/gstsegmentation.cpp b/ext/opencv/gstsegmentation.cpp
index e0401d0e7..b28409a8c 100644
--- a/ext/opencv/gstsegmentation.cpp
+++ b/ext/opencv/gstsegmentation.cpp
@@ -7,7 +7,7 @@
* and adapted. Its license reads:
* "Oct. 3, 2008
* Right to use this code in any way you want without warrenty, support or
- * any guarentee of it working. "
+ * any guarantee of it working. "
*
*
* Permission is hereby granted, free of charge, to any person obtaining a
@@ -72,7 +72,7 @@
* mixture model for real-time tracking with shadow detection", Proc. 2nd
* European Workshop on Advanced Video-Based Surveillance Systems, 2001
* [5] http://opencv.itseez.com/modules/video/doc/motion_analysis_and_object_tracking.html#backgroundsubtractormog2
* [6] Z.Zivkovic, "Improved adaptive Gausian mixture model for background
* subtraction", International Conference Pattern Recognition, UK, August, 2004.
* [7] Z.Zivkovic, F. van der Heijden, "Efficient Adaptive Density Estimation
* per Image Pixel for the Task of Background Subtraction", Pattern Recognition
@@ -230,7 +230,7 @@ gst_segmentation_class_init (GstSegmentationClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
@@ -421,7 +421,7 @@ gst_segmentation_transform_ip (GstOpencvVideoFilter * cvfilter,
* OpenCV MOG2 implements the algorithm described in [2] and [3].
*
* [1] http://opencv.itseez.com/modules/video/doc/motion_analysis_and_object_tracking.html#backgroundsubtractormog2
* [2] Z.Zivkovic, "Improved adaptive Gausian mixture model for background
* subtraction", International Conference Pattern Recognition, UK, Aug 2004.
* [3] Z.Zivkovic, F. van der Heijden, "Efficient Adaptive Density Estimation
* per Image Pixel for the Task of Background Subtraction", Pattern
@@ -630,7 +630,7 @@ clear_stale_entries (codeBook * c)
maxMod Add this (possibly negative) number onto
max level when determining if new pixel is foreground
- minMod Subract this (possibly negative) number from
+ minMod Subtract this (possibly negative) number from
min level when determining if new pixel is foreground
NOTES:
@@ -770,7 +770,7 @@ run_mog2_iteration (GstSegmentation * filter)
[2] and [3].
[1] http://opencv.itseez.com/modules/video/doc/motion_analysis_and_object_tracking.html#backgroundsubtractormog2
- [2] Z.Zivkovic, "Improved adaptive Gausian mixture model for background
+ [2] Z.Zivkovic, "Improved adaptive Gaussian mixture model for background
subtraction", International Conference Pattern Recognition, UK, August, 2004.
[3] Z.Zivkovic, F. van der Heijden, "Efficient Adaptive Density Estimation per
Image Pixel for the Task of Background Subtraction", Pattern Recognition
@@ -72,7 +72,7 @@
* European Workshop on Advanced Video-Based Surveillance Systems, 2001
* [5] http://opencv.itseez.com/modules/video/doc/motion_analysis_and_object_tracking.html#backgroundsubtractormog2
- * [6] Z.Zivkovic, "Improved adaptive Gausian mixture model for background
+ * [6] Z.Zivkovic, "Improved adaptive Gaussian mixture model for background
* subtraction", International Conference Pattern Recognition, UK, August, 2004.
* [7] Z.Zivkovic, F. van der Heijden, "Efficient Adaptive Density Estimation
@@ -421,7 +421,7 @@ gst_segmentation_transform_ip (GstOpencvVideoFilter * cvfilter,
*
* [1] http://opencv.itseez.com/modules/video/doc/motion_analysis_and_object_tracking.html#backgroundsubtractormog2
- * [2] Z.Zivkovic, "Improved adaptive Gausian mixture model for background
+ * [2] Z.Zivkovic, "Improved adaptive Gaussian mixture model for background
* subtraction", International Conference Pattern Recognition, UK, Aug 2004.
* [3] Z.Zivkovic, F. van der Heijden, "Efficient Adaptive Density Estimation